Re-exports
pub use router::build_router;routerpub use actix_web;actix-webpub use anyhow;anyhowpub use chrono;chronopub use config;configpub use tokio;tokiopub use tracing;loggerpub use tracing_actix_web;traceid
Modules
- csrf
csrf - CSRF protection based on the double submit cookie pattern.
- i18n
i18n - logger
logger - Provide logger feature. The inner library uses tracing. See their documents for how to log in the program.
- macros
macros - memorydb
memorydb - In-memory key-value database used for sessions, CSRF tokens, etc.
- request
request - Provide per-request extension data.
- response
response - Provide useful response types.
- response_
build response-build - Build-time code generation for response codes (feature
response-build). - router
router - Declarative router with per-route auth and CSRF configuration.
- security
security - Middleware to add security headers to every response.
- session
session - state
state - Global application state and server handle.
- utils
utils
Macros
Structs
- Error
anyhow - The
Errortype, a wrapper around a dynamic error type.
Type Aliases
- Result
anyhow Result<T, Error>
Attribute Macros
- async_
trait async-trait - main
macros - Attribute macro for the
mainfunction, equivalent to#[actix_web::rt::main(system = "actix_cloud::actix_web::rt::System")].