Module csrf

Module csrf 

Available on crate feature csrf only.
CSRF protection based on the double submit cookie pattern.

The token is stored in a cookie and must be echoed in a header (or a query parameter, generally only for websocket). Checks are applied per route through crate::build_router, and run after the auth checker.

Structs

Middleware
CSRF middleware, configured through crate::build_router.
MiddlewareService