Middleware

Struct Middleware 

pub struct Middleware { /* private fields */ }
Available on crate feature request only.
Middleware inserting Extension into the request extensions.

Implementations

Source

impl Middleware

pub fn new() -> Self

pub fn trace_header<S>(self, s: S) -> Self
where S: Into<String>,

Available on crate feature traceid only.

Set the response header name carrying the trace id (e.g. X-Trace-Id).

pub fn real_ip<F>(self, f: F) -> Self
where F: Fn(&ServiceRequest) -> SocketAddr + 'static,

Set the callback to resolve the client real IP (e.g. reading X-Real-IP).

Defaults to the peer address of the connection.

pub fn lang<F>(self, f: F) -> Self
where F: Fn(&ServiceRequest) -> Option<String> + 'static,

Available on crate feature i18n only.

Set the callback to identify the request language.

Returning None falls back to locale.default in GlobalState.