Crate actix_cloud

Crate actix_cloud 

Actix Cloud is an all-in-one web framework based on Actix Web.

Please refer to our crate.io and Github for more documents.

Re-exports

pub use router::build_router;router
pub use actix_web;actix-web
pub use anyhow;anyhow
pub use chrono;chrono
pub use config;config
pub use tokio;tokio
pub use tracing;logger
pub use tracing_actix_web;traceid

Modules

csrfcsrf
CSRF protection based on the double submit cookie pattern.
i18ni18n
loggerlogger
Provide logger feature. The inner library uses tracing. See their documents for how to log in the program.
macrosmacros
memorydbmemorydb
In-memory key-value database used for sessions, CSRF tokens, etc.
requestrequest
Provide per-request extension data.
responseresponse
Provide useful response types.
response_buildresponse-build
Build-time code generation for response codes (feature response-build).
routerrouter
Declarative router with per-route auth and CSRF configuration.
securitysecurity
Middleware to add security headers to every response.
sessionsession
statestate
Global application state and server handle.
utilsutils

Macros

bailanyhow
Return early with an error.
mapi18n
Make map creation easier.
ti18n
Get I18n text

Structs

Erroranyhow
The Error type, a wrapper around a dynamic error type.

Type Aliases

Resultanyhow
Result<T, Error>

Attribute Macros

async_traitasync-trait
mainmacros
Attribute macro for the main function, equivalent to #[actix_web::rt::main(system = "actix_cloud::actix_web::rt::System")].